<template>
  <ProDialog title="批改信息" v-model="innerVisible" width="1200px" destroy-on-close>
    <ProDialogTableWrapper :height="400">
      <ProTableV2
        :table-data="proTableProps.tableData"
        :columns="column"
        :show-operation-column="false"
      >
        <template #changeType="{ row }"> {{ BatchChangeTypeEnumText[row.changeType] }}</template>
      </ProTableV2>
    </ProDialogTableWrapper>
  </ProDialog>
</template>

<script setup lang="ts">
import { ProDialog, ProTableV2, ProDialogTableWrapper, useTable } from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import { paginateList } from '@/utils';
import { BatchChangeTypeEnumText } from '@/constants';

defineOptions({
  name: 'BatchChangeRecordDetailDialog',
});

type Props = {
  modelValue: boolean;
  form?: {
    id: string;
    staffList: API.InsureBatchBillDetailDto[];
  };
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'onCancel'): void;
}>();

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'changeType',
    name: '批改类型',
  },
  {
    id: '2',
    enCode: 'name',
    name: '姓名',
  },
  {
    id: '3',
    enCode: 'idNumber',
    name: '身份证号',
  },
  {
    id: '4',
    enCode: 'workType',
    name: '雇员工种',
  },
  {
    id: '5',
    enCode: 'gender',
    name: '性别',
  },
  {
    id: '6',
    enCode: 'age',
    name: '年龄',
  },
  {
    id: '7',
    enCode: 'birthDay',
    name: '出生日期',
  },
  {
    id: '8',
    enCode: 'phoneNumber',
    name: '电话号码',
  },
  {
    id: '9',
    enCode: 'modifyInfo',
    name: '修改内容',
  },
];

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

watch(
  () => props.modelValue,
  (val) => {
    if (val) {
      getList();
    }
  },
  {
    immediate: true,
  }
);

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      return Promise.resolve({
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          totalCount: props.form.staffList.length,
        },
        data: paginateList(props.form.staffList, pageIndex, pageSize),
      });
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'id', order: OrderInputType.Asc }],
    },
  }
);
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
